@@ -285,7 +285,7 @@ class Repository:
         Executes sql query. Make sure you use :parameter for parameters
         '''
         q = text(query)
-        result = self.engine.execute(q, parameters).mappings().all()
+        result = self.session.execute(q, parameters).mappings().all()
         return result
 
     def assign(self, entity, prop, value):
